@@ -13,8 +13,8 @@ def thumb_querie(id:int) -> typing.Union[tuple, str]:
         select_command = "SELECT * FROM picturereference WHERE id=%(int)s;"
         cursor.execute(select_command, id)
         pic_ref = cursor.fetchone()[0]
-    except:
-        return "error"
+    except Exception as e:
+        return e
     finally:
         if connection is not None:
             connection.close()
